@@ -3,7 +3,7 @@
 
 #define N 20
 
-#if (sun && __svr4__)
+#if (sun && __svr4__) || defined(__hpux) || defined(_SEQUENT_)
 long lrand48();
 #define random lrand48
 #else
@@ -39,6 +39,6 @@ int main()
   /* cause an error */
   /*  s = [heap elementAtIndex:999].short_int_u; */
 
-  [heap free];
+  [heap release];
   exit(0);
 }
